Name: tiny-utf8
Summary: Unicode (UTF-8) capable std::string replacement
License: BSD-3-Clause

# This is a header-only library.
# All debuginfo we generate along the way relates to test executables only.
%global debug_package %{nil}

Version: 4.4.3
Release: 1%{?dist}

URL: https://github.com/DuffsDevice/tiny-utf8
Source0: %{URL}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: gmock-devel
BuildRequires: graphviz
BuildRequires: gtest-devel
BuildRequires: make

BuildArch: noarch

%global desc %{expand:
tiny-utf8 is a library for extremely easy integration of Unicode into
an arbitrary C++11 project. The library consists solely of the class
utf8_string, which acts as a drop-in replacement for std::string.
Its implementation is successfully in the middle between small memory
footprint and fast access. All functionality of std::string is therefore
replaced by the corresponding codepoint-based UTF-32 version - translating
every access to UTF-8 under the hood.}

%description
%{desc}


%package devel
Summary: %{summary}

%description devel
%{desc}

This package contains files used to build programs using tiny-utf8.


%package doc
Summary: Documentation for %{name}

%description doc
This package contains developer documentation for %{name},
in text and HTML format.


%prep
%autosetup -p1


%build
%cmake -DTINYUTF8_BUILD_DOC=ON -DTINYUTF8_BUILD_TESTING=ON
%cmake_build
%cmake_build --target api_doc


%install
%cmake_install

# Fix .cmake install dir
install -d -m755 %{buildroot}%{_datadir}/cmake
mv %{buildroot}%{_datadir}/tinyutf8/cmake %{buildroot}%{_datadir}/cmake/tinyutf8
rmdir %{buildroot}%{_datadir}/tinyutf8

# Install documentation
install -d -m755 %{buildroot}%{_pkgdocdir}
cp -a README.md %{buildroot}%{_pkgdocdir}
cp -a %{__cmake_builddir}/docs/html %{buildroot}%{_pkgdocdir}


%check
./%{__cmake_builddir}/test/tinyutf8_test


%files devel
%license LICENCE
%{_includedir}/tinyutf8/
%{_datadir}/cmake/tinyutf8/

%files doc
%doc %{_pkgdocdir}


%changelog
* Wed Feb 26 2025 Artur Frenszek-Iwicki <fedora@svgames.pl> - 4.4.3-1
- Initial packaging
